@@ -12,6 +12,7 @@ mod conditional;
 mod delimiters;
 mod dotenv;
 mod edit;
+mod equals;
 mod error_messages;
 mod evaluate;
 mod examples;
@@ -34,4 +35,5 @@ mod string;
 mod sublime_syntax;
 mod subsequents;
 mod tempdir;
+mod undefined_variables;
 mod working_directory;
